/* This file is part of Idest.
   Copyright (C) 2009 Sergey Poznyakoff
 
   Idest is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.
 
   Idest is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with Idest.  If not, see <http://www.gnu.org/licenses/>. */

#include <config.h>
#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <getopt.h>
#include <error.h>
#include <progname.h>
#include <xalloc.h>
#include <gl_linked_list.h>
#include <argmatch.h>
#include <backupfile.h>
#include <id3tag.h>

#define _(s) s
#define N_(s) s

#include "id3v1.h"

#define DEFAULT_ED_LIST "title,album,track,comment,artist,year,genre"

enum item_ids {
	item_title,
	item_artist,
	item_album,
	item_year,
	item_comment,
	item_track,
	item_genre
};
	
struct ed_item {
	char *name;                /* Printable name */
	char id[5];                /* Item ID */
	union {
		gl_list_t vlist;   /* List of strings, used with --query */
		char *value;       /* New value, used with --set */
	} v;
};

extern int latin1_option;
extern enum backup_type backup_type;
extern char *backup_dir;
extern gl_list_t ed_list;

void set_id3v1(const char *name, const struct id3v1_block *);
void query_id3v1(const char *name);
void del_id3v1(const char *name);

void set_id3v2(const char *name);
void query_id3v2(const char *name);
void del_id3v2(const char *name);


/* slist.c */
typedef int (*string_list_action_fn) (const char *, void *);

gl_list_t new_string_list(bool allow_duplicates);
int do_string_list(gl_list_t list, string_list_action_fn action, void *data);
void concat_string_list(gl_list_t list, gl_list_t addlist);
void print_string_list(FILE *fp, gl_list_t list);


void ed_list_add_item(const char *id, gl_list_t list);
void ed_list_print(void);
void ed_list_add_assignment(const char *name, const char *value);


/* backup.c */
int backup_file(const char *file);
